"""Add column date_locked to Update table

Revision ID: 3c72757fa59e
Revises: 3aae6532b560
Create Date: 2016-05-15 11:33:14.849331

"""

# revision identifiers, used by Alembic.
revision = '3c72757fa59e'
down_revision = 'a1d8dae7cc'

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('updates', sa.Column('date_locked', sa.DateTime(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('updates', 'date_locked')
    ### end Alembic commands ###
