"""Remove the Release.metrics PickleCol

Revision ID: 5735e34a4ba
Revises: 6a438fe37fd
Create Date: 2014-06-16 10:06:40.082113

"""

# revision identifiers, used by Alembic.
revision = '5735e34a4ba'
down_revision = '6a438fe37fd'

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('releases', 'metrics')
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('releases', sa.Column('metrics', postgresql.BYTEA(), autoincrement=False, nullable=True))
    ### end Alembic commands ###
