"""Add a description field to the stacks

Revision ID: d58f9439269
Revises: 2861bb4e77b1
Create Date: 2014-08-21 12:50:05.920845

"""

# revision identifiers, used by Alembic.
revision = 'd58f9439269'
down_revision = '2861bb4e77b1'

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('stacks', sa.Column('description', sa.UnicodeText(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('stacks', 'description')
    ### end Alembic commands ###
